# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Contexts(Component):
    """A Contexts component.
A component exposing the Glue42 Contexts API.

Keyword arguments:

- id (optional):
    The ID of this component. Used to identify Dash components in
    callbacks.  The ID must be unique across all components in an app.

- destroy (dict; optional):
    Destroys a context and all the data associated with it.

    `destroy` is a dict with keys:

    - name (string; required):
        Name of the context to be removed.

- set (dict; optional):
    Property for setting a new context value.  All properties of the
    specified context object will be removed and replaced with the
    ones supplied in the data property.  An object that will replace
    the context value completely.

    `set` is a dict with keys:

    - data (dict; optional):
        The object that will be applied to the context.

    - name (string; required):
        Name of the context to be replaced.

- setPath (dict; optional):
    Sets a path in the context to some value. Use this to update
    values that are not on top level in the context.

    `setPath` is a dict with keys:

    - data (boolean | number | string | dict | list; optional):
        The object that will be applied to the context.

    - name (string; required):
        Name of the context to be updated.

    - path (optional):
        Path to be updated. Path should be in the format
        \"prop1.prop2\".

- setPaths (dict; optional):
    Sets multiple paths in the context to some values in a single
    command.

    `setPaths` is a dict with keys:

    - name (string; required):
        Name of the context to be updated.

    - paths (list; required):
        Array of paths and their values to be updated.

- setProps (optional):
    Dash-assigned callback that should be called to report property
    changes to Dash in order to make them available for callbacks.

- update (dict; optional):
    Property for updating a shared context with the supplied object.
    Updates only the specified context properties. Any other existing
    context properties will remain intact.  If the context does not
    exist, the it will be created.

    `update` is a dict with keys:

    - data (dict; optional):
        The object that will be applied to the context.

    - name (string; required):
        Name of the context to be updated."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_glue42'
    _type = 'Contexts'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, update=Component.UNDEFINED, set=Component.UNDEFINED, setPath=Component.UNDEFINED, setPaths=Component.UNDEFINED, destroy=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'destroy', 'set', 'setPath', 'setPaths', 'setProps', 'update']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'destroy', 'set', 'setPath', 'setPaths', 'setProps', 'update']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(Contexts, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class MethodRegister(Component):
    """A MethodRegister component.
A component exposing the ability to register a Glue42 Interop method.

Keyword arguments:

- id (optional):
    The ID of this component. Used to identify Dash components in
    callbacks.  The ID must be unique across all components in an app.

- definition (string | dict; optional):
    Method name or an object holding the method name, signature and
    other properties of the method.

- error (dict; optional):
    An error to return in case the method registration fails.

- invoke (dict; optional):
    Property for invoking an Interop method handler.

    `invoke` is a dict with keys:

    - args (dict; optional):
        Invocation arguments.

    - caller (dict; optional):
        The Interop client which has invoked the method.

    - invocationId (string; optional):
        An ID to correlate the method invocation to its result.

- loading_state (dict; optional):
    Dash-assigned prop holding the loading state object coming from
    `dash-renderer`.

    `loading_state` is a dict with keys:

    - is_loading (boolean; optional):
        Determines whether the component is loading or not.

- methodResponseTimeoutMs (number; default 30000):
    Timeout to wait for the handler to reply. Set this prop to
    configure how much time the component should wait for a response
    from the Dash backend.  Default is 30000 ms.

- result (dict; optional):
    Property for returning a result or an error to the caller.

    `result` is a dict with keys:

    - error (dict; optional):
        Holds the returned error when the method invocation has
        failed.

    - invocationId (string; optional):
        An ID to correlate the method invocation to its result.

    - invocationResult (dict; optional):
        The actual result from the method invocation.

- returns (boolean; default False):
    Specify whether the method is void or returns a result.  Default
    is `False`.

- setProps (optional):
    Dash-assigned callback that should be called to report property
    changes to Dash in order to make them available for callbacks."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_glue42'
    _type = 'MethodRegister'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, loading_state=Component.UNDEFINED, definition=Component.UNDEFINED, methodResponseTimeoutMs=Component.UNDEFINED, error=Component.UNDEFINED, returns=Component.UNDEFINED, result=Component.UNDEFINED, invoke=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'definition', 'error', 'invoke', 'loading_state', 'methodResponseTimeoutMs', 'result', 'returns', 'setProps']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'definition', 'error', 'invoke', 'loading_state', 'methodResponseTimeoutMs', 'result', 'returns', 'setProps']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(MethodRegister, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Glue42(Component):
    """A Glue42 component.
The Glue42 initializer component. The component should be placed at the root of the application.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The children of this component.

- id (optional):
    The ID of this component. Used to identify Dash components in
    callbacks.  The ID must be unique across all components in an app.

- fallback (a list of or a singular dash component, string or number; optional):
    An optional component to display while initializing Glue42.

- isEnterprise (boolean; optional):
    Indicates whether the application is running in Glue42 Enterprise
    or Glue42 Core.

- setProps (optional):
    Dash-assigned callback that should be called to report property
    changes to Dash in order to make them available for callbacks.

- settings (dict; default {
    type: CoreApplicationTypes.Client,
}):
    Optional. A \"settings\" object containing configuration objects
    for the Glue42 library.

    `settings` is a dict with keys:

    - desktop (dict; optional):
        Optional. An object with one property: config. The config
        property accepts a configuration object for the
        @glue42/desktop library used in Glue42 Enterprise.  You should
        define this object if your app is a Glue42 Enterprise app.

        `desktop` is a dict with keys:

        - config (dict; optional)

    - type (a value equal to: CoreApplicationTypes.Client, CoreApplicationTypes.Platform; optional):
        Optional. Accepts either \"platform\" or \"client\" as a
        value. Specifies whether this is a Main app or a Web Client in
        the context of Glue42 Core. The default is \"client\".

    - web (dict; optional):
        Optional. An object with one property: config. The config
        property accepts a configuration object for the Glue42 Web
        library.  You should define this object if your app is a Web
        Client.

        `web` is a dict with keys:

        - config (dict; optional)

    - webPlatform (dict; optional):
        Optional. An object with one property: config. The config
        property accepts a configuration object for the Web Platform
        library.  You should define this object if your app is a Main
        app in the context of Glue42 Core.

        `webPlatform` is a dict with keys:

        - config (dict; optional)"""
    _children_props = ['fallback']
    _base_nodes = ['fallback', 'children']
    _namespace = 'dash_glue42'
    _type = 'Glue42'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, isEnterprise=Component.UNDEFINED, settings=Component.UNDEFINED, fallback=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'fallback', 'isEnterprise', 'setProps', 'settings']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'fallback', 'isEnterprise', 'setProps', 'settings']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(Glue42, self).__init__(children=children, **args)



import pathlib
import json
import os
from setuptools import setup

with open('package.json') as f:
    package = json.load(f)

package_name = package["name"].replace(" ", "_").replace("-", "_")

HERE = pathlib.Path(__file__).parent
readme = (HERE / "README.md").read_text()

setup(
    name=package_name,
    version=package["version"],
    author=package['author'].get("name"),
    packages=[package_name],
    include_package_data=True,
    license=package['license'],
    description=package.get('description', package_name),
    long_description=readme,
    long_description_content_type="text/markdown",
    install_requires=[],
    classifiers = [
        'Framework :: Dash',
    ],
    project_urls={
        'Home': 'https://glue42.com/',
        'Documentation': 'https://docs.glue42.com/getting-started/how-to/glue42-enable-your-app/dash/index.html'
    },
    python_requires=">=3.6"
)
